llvm: The LLVM Compiler Infrastructure, including the Clang C/C++/Objective-C compiler
======================================================================================

Description
-----------

The LLVM Project is a collection of modular and reusable compiler and toolchain technologies.

Clang is an "LLVM native" C/C++/Objective-C compiler.

The libc++ and libc++ ABI projects provide a standard conformant and high-performance
implementation of the C++ Standard Library, including full support for C++11 and C++14.

License
-------

Apache 2.0 License with LLVM exceptions

Upstream Contact
----------------

https://llvm.org/
